@@ -9,7 +9,7 @@ example-mrdvt92.pl - GD::Graph::Polar example
 
 =head1 SAMPLE OUTPUT
 
-L<http://search.cpan.org/src/MRDVT/GD-Graph-Polar-0.16/bin/example-mrdvt92.png>
+L<http://search.cpan.org/src/MRDVT/GD-Graph-Polar-0.16/scripts/example-mrdvt92.png>
 
 =cut
 
